package com.yaohun.consumereward.data;

import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;

import java.io.File;
import java.io.IOException;
import java.util.List;

import org.bukkit.configuration.file.YamlConfiguration;
import java.io.File;
import java.io.IOException;
import java.util.*;

public class PlayerData {

    /**
     * 玩家数据类，用于管理玩家的奖励接收情况
     */
    private final String playerName;

    /**
     * 存储玩家已接收的奖励列表
     * 使用 Set 而不是 List 来提升 contains 方法的性能，因为 Set 的查找效率更高
     */
    private final Set<String> rewardList;

    /**
     * 构造玩家数据对象，根据玩家名称加载其奖励接收数据
     *
     * @param playerName 玩家名称，用于标识和加载玩家数据
     */
    public PlayerData(String playerName) {
        this.playerName = playerName;
        // 加载玩家的奖励数据文件
        File file = new File("plugins/AuData/ConsumeReward", playerName + ".yml");
        YamlConfiguration config = YamlConfiguration.loadConfiguration(file);
        List<String> rewards = config.getStringList("RewardsReceive");
        // 使用 LinkedHashSet 保持插入顺序，避免重复
        this.rewardList = new LinkedHashSet<>(rewards);
    }

    /**
     * 检查玩家是否已经接收了指定的奖励
     *
     * @param rewardKey 奖励的唯一键，用于标识特定的奖励
     * @return 如果玩家已经接收了指定的奖励，则返回 true；否则返回 false
     */
    public boolean isReceive(String rewardKey) {
        return rewardList.contains(rewardKey);
    }

    /**
     * 向玩家的奖励列表中添加一个新的奖励
     *
     * @param rewardKey 新增奖励的唯一键，用于标识特定的奖励
     */
    public void addRewardReceive(String rewardKey) {
        rewardList.add(rewardKey);
    }

    /**
     * 设置玩家的奖励列表，替换现有的奖励列表
     *
     * @param rewardList 新的奖励列表，不含重复项
     */
    public void setRewardList(List<String> rewardList) {
        this.rewardList.clear();
        // 使用 LinkedHashSet 包装列表以避免重复项，并保持插入顺序
        this.rewardList.addAll(new LinkedHashSet<>(rewardList));
    }

    /**
     * 保存玩家的奖励接收数据到文件
     * 将 Set 类型的 rewardList 转换回 List 类型以保存到 YAML 文件中
     */
    public void savePlayerData() {
        File file = new File("plugins/AuData/ConsumeReward", playerName + ".yml");
        YamlConfiguration config = YamlConfiguration.loadConfiguration(file);
        // 将 Set 转换回 List 以保存
        config.set("RewardsReceive", new ArrayList<>(rewardList));
        try {
            config.save(file);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
