package com.yaohun.consumereward.data;

import org.bukkit.Bukkit;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.entity.Player;

import java.util.List;

/**
 * RewardData 类用于存储和管理消费奖励的相关数据
 */
public class RewardData {

    // 奖励的唯一键值
    private String rewardKey;
    // 奖励在界面中的槽位
    private int slot;
    // 需要消耗的金额
    private int needConsume;
    // 额外背包槽位奖励数量
    private int backpackSlot;
    // 物品的NBT数据
    private String itemNbt;
    // 奖励的描述信息
    private List<String> rewardLore;
    // 执行的命令列表
    private List<String> commandList;

    /**
     * 构造一个新的 RewardData 对象
     *
     * @param rewardKey 奖励的唯一键值
     * @param section 配置文件的 ConfigurationSection 对象，用于读取奖励数据
     */
    public RewardData(String rewardKey, ConfigurationSection section){
        this.rewardKey = rewardKey;
        // 从配置中读取奖励数据
        this.slot = section.getInt(rewardKey+".slot");
        this.needConsume = section.getInt(rewardKey+".needConsume");
        this.backpackSlot = section.getInt(rewardKey+".backpackSlot");
        this.itemNbt = section.getString(rewardKey+".itemNbt");
        this.rewardLore = section.getStringList(rewardKey+".rewardLore");
        this.commandList = section.getStringList(rewardKey+".commandList");
    }

    // 以下为获取奖励数据的getter方法
    public String getRewardKey() {
        return rewardKey;
    }
    public int getSlot() {
        return slot;
    }
    public int getNeedConsume() {
        return needConsume;
    }
    public int getBackpackSlot() {
        return backpackSlot;
    }
    public String getItemNbt() {
        return itemNbt;
    }
    public List<String> getRewardLore() {
        return rewardLore;
    }

    /**
     * 发放奖励给指定玩家
     *
     * @param player 接收奖励的玩家对象
     */
    public void carryOutReward(Player player){
        String playerName = player.getName();
        // 遍历所有命令并执行
        for(String command : commandList) {
            if (command.contains("msg:")) {
                // 如果是消息命令，去掉前缀后发送消息
                player.sendMessage(command.replace("msg:", "").replace("&", "§"));
                continue;
            }
            // 替换命令中的玩家名称占位符%p%为真实名称
            command = command.replace("%p%", playerName);
            command = command.replace("%player%", playerName);
            // 执行命令
            Bukkit.dispatchCommand(Bukkit.getConsoleSender(),command);
        }
        // 记录日志
        Bukkit.getLogger().info("[消费奖励 - 发放] " + player.getName() + " 已执行奖励命令: " + rewardKey);
    }
}
