package com.yaohun.consumereward.util;

import com.yaohun.aurechargedata.api.ConsumeAPI;
import com.yaohun.aurechargedata.util.TimeType;
import com.yaohun.consumereward.config.Config;
import com.yaohun.consumereward.data.PlayerData;
import com.yaohun.consumereward.data.RewardData;
import me.Demon.DemonPlugin.data.NbtItem;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;

import java.util.ArrayList;
import java.util.List;

/**
 * StackUtil类用于处理物品堆的工具方法
 */
public class StackUtil {

    /**
     * 获取玩家的消费数据信息物品堆
     *
     * @param playerName 玩家名
     * @return 包含玩家消费数据的物品堆
     */
    public static ItemStack getDataInfo(String playerName){
        // 获取配置中的数据信息物品堆模板
        ItemStack stack = Config.getItemStack("dataInfo");
        ItemMeta meta = stack.getItemMeta();
        List<String> lore = meta.getLore();

        // 遍历物品堆的附带信息，替换{name}和{consume}占位符
        for (int i = 0; i < lore.size(); i++){
            String line = lore.get(i);
            if(line.contains("{name}")){
                lore.set(i, line.replace("{name}", playerName));
                continue;
            }
            if(line.contains("{consume}")){
                int consumeValue = ConsumeAPI.getConsumeData(playerName, TimeType.ANNUAL);
                lore.set(i, line.replace("{consume}", String.valueOf(consumeValue)));
            }
        }

        meta.setLore(lore);
        stack.setItemMeta(meta);
        return stack;
    }

    /**
     * 获取玩家的奖励礼品盒物品堆
     *
     * @param playerData 玩家数据对象
     * @param rewardData 奖励数据对象
     * @return 包含奖励信息的物品堆
     */
    public static ItemStack getRewardGiftBox(PlayerData playerData, RewardData rewardData){
        String rewardKey = rewardData.getRewardKey();
        ItemStack stack = Config.getItemStack("rewardGiftBox");
        ItemMeta meta = stack.getItemMeta();
        List<String> newLore = new ArrayList<>();

        // 根据玩家是否已领取奖励和奖励的附带信息更新物品堆的附带信息
        for (String line : meta.getLore()){
            if(line.contains("{stats}")){
                if(playerData.isReceive(rewardKey)){
                    newLore.add(line.replace("{stats}", Config.langData.getMessage("statsOK")));
                } else {
                    newLore.add(line.replace("{stats}", Config.langData.getMessage("statsNO")));
                }
            } else if(line.contains("{rewardLore}")){
                newLore.addAll(rewardData.getRewardLore());
            } else {
                newLore.add(line);
            }
        }

        meta.setLore(newLore);
        stack.setItemMeta(meta);

        // 使用NbtItem来设置物品堆的特殊数据
        NbtItem nbtItem = new NbtItem(stack);
        nbtItem.setString("rewardKey", rewardKey);
        return nbtItem.getItem();
    }
}
